elbaue: This is an example vegetation dataset to be included in...

elbaueR Documentation

This is an example vegetation dataset to be included in package vegdata. Use tv.veg('elbaue') and tv.site('elbaue') to load.

Description

This is an example vegetation dataset to be included in package vegdata. Use tv.veg('elbaue') and tv.site('elbaue') to load.

Author(s)

Florian Jansen

https://www.vegetweb.de


vegdata documentation built on July 8, 2026, 1:08 a.m.