syntab: Syntaxonomic frequency tables

syntabR Documentation

Syntaxonomic frequency tables

Description

Calculate and display relative or absolute frequency tables with or without use of function multipatt from package indicspecies

Usage

syntab(
  veg,
  clust,
  type = c("rel", "abs", "mean.cover"),
  mupa,
  dec = 0,
  refl,
  ...
)

## S3 method for class 'syntab'
print(x, zero.print = ".", trait, limit = 1, minstat = 0, alpha = 0.05, ...)

Arguments

veg

Vegetation dataframe

clust

Vector with cluster information with length equal to number of rows of veg

type

Relative (species or type) or absolute frequency, mean species response values or strength of association.

mupa

Either logical for (not) using multipatt from package indicspecies to detect significance of cluster association strength or supply output from previous use of multipatt.

dec

Number of decimals in result.

refl

Name of Turboveg taxonomic reference list to use for fullnames.

...

additional arguments

x

Object from function syntab

zero.print

character to fill empty cells

trait

prints ecological indicators of species

limit

minimum frequency to display

minstat

minimum multipatt statistic

alpha

Significance level

Author(s)

Florian Jansen florian.jansen@uni-rostock.de

See Also

Package indicspecies with function multipatt for indicator species analysis along multiple cluster combinations

Examples

## Not run: 
 elbaue <- tv.veg('elbaue')
 elbaue.env <- tv.site('elbaue')
 clust <- vector('integer', nrow(elbaue.env))
 clust[elbaue.env$MGL < -50 & elbaue.env$SDGL < 50] <- 1
 clust[elbaue.env$MGL < -50 & elbaue.env$SDGL >= 50] <- 2
 clust[elbaue.env$MGL >= -50 & elbaue.env$SDGL >= 50] <- 3
 clust[elbaue.env$MGL >= -50 & elbaue.env$SDGL < 50] <- 4
 levels(clust) <- c('dry.ld','dry.hd', 'wet.hd','wet.ld')
 st <- syntab(elbaue, clust, mupa=TRUE)
 traits <- tv.traits()
 m <- match(rownames(st$syntab), traits$LETTERCODE, nomatch = 0)
 trait <- traits[m, c("OEK_F","OEK_N")]
 rownames(trait) <- traits$LETTERCODE[m]
 print(st, limit=30, trait=trait)
 #'  Configure the syntaxonomic table
 sttable <- st$syntab
 sttable <- sttable[sttable$p.value < 0.05 & !is.na(sttable$p.value),
 !names(sttable) %in% c('stat')]
 taxa <- tax(rownames(sttable))
 rownames(sttable) <- taxa[match(rownames(sttable), taxa$LETTERCODE, nomatch = 0),'TaxonName']
 write.csv(sttable, 'sttable.csv')

## End(Not run)


vegdata documentation built on July 8, 2026, 1:08 a.m.