| tax | R Documentation |
Input is either species number (integer), shortletter (7 characters) or full (exact!) species name.
tax(x, refl = tax.refl(), syn = TRUE, concept = NULL, strict = FALSE, idtype)
x |
Species number, lettercode or species name(s) |
refl |
Taxonomic reference list |
syn |
Return also synonym names |
concept |
Name of the file with an alternative taxon view stored in the reference list directory, see details. |
strict |
Exact match or partial matching with |
idtype |
is x of type 'is_id', 'is_shortletter', or 'is_scientific' |
concept: GermanSL is a list with a single taxon view according to the standard lists of the different taxon groups (e.g Wisskirchen and Haeupler for higher plants, see). Nevertheless a huge number of synonyms is included which allows in many cases the transformation into different concepts. For illustration the concept of Armeria maritima from Korneck 1996 is included, which accepts e.g. Armeria maritima ssp. bottendorfensis. parse.taxa: parse genus and epitheta from name strings. taxname.removeAuthors Remove name authors from full scientific name strings.
Florian Jansen florian.jansen@uni-rostock.de
Jansen, F. and Dengler, J. (2008) GermanSL - eine universelle taxonomische Referenzliste für Vegetationsdatenbanken. Tuexenia, 28, 239-253.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.