tv.biblio: Check bibliographic references from Turboveg codes
Description
Check bibliographic references from Turboveg codesUsage
tv.biblio(x='all', site, quiet=FALSE, tv_home, dict = '', iconv = "WINDOWS-1252", ...)
Arguments
x
Turboveg reference code(s), e.g. "000001"
site
If you want to calculate the number of vegetation plots per reference, please indicate the header data, see tv.site quiet
If you want to print the reference to the screen.
tv_home
Turbowin installation path. If not specified function tv.home tries to discover. dict
Name of Turboveg Dictionary (term lists for header data) if not the default one.
iconv
encoding of Turboveg files if different from your actual environment
Value
- Dataframe of (selected) biblioreferences (when assigned to an object).