| tv.site | R Documentation |
Loading Turboveg header data and do basic data evaluation. Empty columns are eliminated and warnings about possibly wrong '0' values are performed
tv.site(
db,
tv_home,
drop = TRUE,
common.only = FALSE,
check.relevenumbers = TRUE,
replace.names,
...
)
db |
(character) Name of your Turboveg database(s). Directory name containing tvabund.dbf, tvhabita.dbf and tvwin.set. |
tv_home |
(character) Turbowin installation path. Optional, if Turbowin is either on "C:/Turbowin" or "C:/Programme/Turbowin". |
drop |
(logical) Drop variables without values. |
common.only |
(logical) Import only header data with the same name in all databases. |
check.relevenumbers |
(logical) Are duplicate PlotObservationID's allowed. Default is FALSE. |
replace.names |
(data.frame) replace variable names. Useful if using multiple source databases. Data frame with names to be replaced in first and replacing names in second column. |
... |
Additional options like |
Please specify pathnames below but not above Turbowin/Data. Can be a single database or a character vector of multiple databases. In the latter case you have to assure, that all databases use the same taxonomic reference list. You can use the example in the final output line to make a summary statistic for attributes with potentially misleading '0' values. Just delete the \" at beginning and end.
data.frame of site variables.
Florian Jansen florian.jansen@uni-rostock.de
#'#' Survey Area
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.